@@ -2,11 +2,13 @@
 #this repository contains the full copyright notices and license terms.
 {
     'name': 'Timesheet',
+    'name_bg_BG': 'График',
     'name_de_DE': 'Zeiterfassung',
     'name_es_CO': 'Hoja de Asistencia',
     'name_es_ES': 'Partes de trabajo',
     'name_fr_FR': 'Feuille de présence',
-    'version': '1.8.2',
+    'name_nl_NL': 'Tijdregistratie',
+    'version': '2.0.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -18,6 +20,15 @@ And with reports:
     - Hours per work
     - Hours per employee per week
     - Hours per employee per month
+''',
+    'description_bg_BG': '''Модул за график с:
+    - Задачи
+    - Редове от график
+
+Прилежащи справки:
+    - Часове за задача
+    - Часове по служител за седмица
+    - Часове по служител за месец
 ''',
     'description_de_DE': '''Zeiterfassungsmodul mit:
     - Aufgaben
@@ -54,6 +65,15 @@ Et les rapports:
     - Heures par tâche
     - Heures par employé par semaine
     - Heures par employé par mois
+''',
+    'description_nl_NL': '''Tijdverantwoordingmodule met:
+    - Werken
+    - Tijdboekingen
+
+Bijbehorende rapporten:
+    - Uren per werk
+    - Uren per werknemer per week
+    - Uren per werknemer per maand
 ''',
     'depends': [
         'ir',
@@ -67,9 +87,11 @@ Et les rapports:
         'line.xml',
     ],
     'translation': [
+        'bg_BG.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
         'fr_FR.csv',
+        'nl_NL.csv',
     ],
 }
